@@ -1,4 +1,4 @@
-# Allow users to build circuit values directly.
+"""Allow users to build circuit values directly."""
 from circuit.circuit import\
     operation, op, gate,\
     signature, circuit
